# filename

```
usage: filename [-h] path

Get group or dataset filename

positional arguments:
  path        Path to group or dataset

optional arguments:
  -h, --help  show this help message and exit
```
